OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nepavyksta rašyti į \"config\" katalogą!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Tai, dažniausiai, gali būti ištaisyta suteikiant saityno serveriui rašymo prieigą prie konfigūracijos katalogo",
    "See %s" : "Žiūrėkite %s",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Tai, dažniausiai, gali būti pataisyta, suteikiant saityno serveriui rašymo prieigą prie konfigūracijos katalogo. Žiūrėkite %s",
    "Sample configuration detected" : "Aptiktas konfigūracijos pavyzdys",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Pastebėta, kad nukopijuota pavyzdinė konfigūracija. Tai gali pažeisti jūsų diegimą ir yra nepalaikoma. Prieš atliekant pakeitimus config.php faile, prašome perskaityti dokumentaciją.",
    "%1$s and %2$s" : "%1$s ir %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ir %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ir %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ir %5$s",
    "Groupware bundle" : "Grupinio darbo įrangos rinkinys",
    "PHP %s or higher is required." : "Reikalinga PHP %s arba aukštesnė.",
    "PHP with a version lower than %s is required." : "Reikalinga žemesnė nei %s PHP versija. ",
    "Following databases are supported: %s" : "Yra palaikomos šios duomenų bazės: %s",
    "The command line tool %s could not be found" : "Nepavyko rasti komandų eilutės įrankio %s",
    "The library %s is not available." : "Biblioteka %s nėra prieinama.",
    "Following platforms are supported: %s" : "Yra palaikomos šios platformos: %s",
    "Server version %s or higher is required." : "Reikalinga %s arba aukštesnė serverio versija ",
    "Server version %s or lower is required." : "Reikalinga %s arba žemesnė serverio versija. ",
    "Logged in user must be an admin" : "Prisijungęs naudotojas privalo būti administratoriumi",
    "Wiping of device %s has started" : "Įrenginio %s duomenų ištrynimas pradėtas",
    "Wiping of device »%s« has started" : "Įrenginio »%s« duomenų ištrynimas pradėtas",
    "»%s« started remote wipe" : "»%s« pradėjo nuotolinių duomenų ištrynimą",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Įrenginys ar programa »%s« pradėjo nuotolinių duomenų ištrynimo procesą. Procesui užsibaigus, gausite dar vieną el. laišką",
    "Wiping of device %s has finished" : "Įrenginio %s duomenų ištrynimas užbaigtas",
    "Wiping of device »%s« has finished" : "Įrenginio »%s« duomenų ištrynimas užbaigtas",
    "»%s« finished remote wipe" : "»%s« užbaigė nuotolinių duomenų ištrynimą",
    "Device or application »%s« has finished the remote wipe process." : "Įrenginys ar programa »%s« užbaigė nuotolinių duomenų ištrynimo procesą.",
    "Remote wipe started" : "Nuotolinių duomenų ištrynimas pradėtas",
    "A remote wipe was started on device %s" : "Nuotolinių duomenų ištrynimas buvo pradėtas įrenginyje %s",
    "Remote wipe finished" : "Nuotolinių duomenų ištrynimas užbaigtas",
    "The remote wipe on %s has finished" : "Nuotolinių duomenų ištrynimas ties %s yra užbaigtas",
    "Authentication" : "Tapatybės nustatymas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Invalid image" : "Neteisingas paveikslas",
    "Avatar image is not square" : "Avataro paveikslas nėra kvadratinis",
    "today" : "šiandien",
    "tomorrow" : "rytoj",
    "yesterday" : "vakar",
    "_%n day ago_::_%n days ago_" : ["prieš %n dieną","prieš %n dienas","prieš %n dienų","prieš %n dienų"],
    "last month" : "praeitą mėnesį",
    "_%n month ago_::_%n months ago_" : ["prieš %n mėnesį","prieš %n mėnesius","prieš %n mėnesių","prieš %n mėnesių"],
    "last year" : "praeitais metais",
    "_%n year ago_::_%n years ago_" : ["prieš %n metus","prieš %n metus","prieš %n metų","prieš %n metų"],
    "_%n hour ago_::_%n hours ago_" : ["prieš %n valandą","prieš %n valandas","prieš %n valandų","prieš %n valandų"],
    "_%n minute ago_::_%n minutes ago_" : ["prieš %n minutę","prieš % minutes","prieš %n minučių","prieš %n minučių"],
    "seconds ago" : "prieš keletą sekundžių",
    "Empty file" : "Tuščias failas",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulio, kurio ID: %s, nėra. Prašome jį įjungti savo programėlių nustatymuose arba susisiekti su savo administratoriumi.",
    "File name is a reserved word" : "Failo pavadinimas negalimas, žodis rezervuotas",
    "File name contains at least one invalid character" : "Failo vardas sudarytas iš neleistinų simbolių",
    "File name is too long" : "Failo pavadinimas per ilgas",
    "Empty filename is not allowed" : "Tuščias failo pavadinimas nėra leidžiamas",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Programėlė \"%s\" negali būti įdiegta, kadangi negalima perskaityti appinfo failo.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Programėlė \"%s\" negali būti įdiegta, kadangi ji nėra suderinama su serverio versija.",
    "__language_name__" : "Lietuvių",
    "This is an automatically sent email, please do not reply." : "Tai yra automatinis pranešimas, prašome neatsakyti.",
    "Help" : "Pagalba",
    "Apps" : "Programėlės",
    "Settings" : "Nustatymai",
    "Log out" : "Atsijungti",
    "Users" : "Naudotojai",
    "Unknown user" : "Nežinomas naudotojas",
    "Overview" : "Apžvalga",
    "Basic settings" : "Pagrindiniai nustatymai",
    "Sharing" : "Bendrinimas",
    "Security" : "Saugumas",
    "Groupware" : "Grupinio darbo įranga",
    "Additional settings" : "Papildomi nustatymai",
    "Personal info" : "Asmeninė informacija",
    "Mobile & desktop" : "Mobilieji ir darbalaukiai",
    "%s enter the database username and name." : "%s įrašykite duomenų bazės naudotojo vardą ir pavadinimą.",
    "%s enter the database username." : "%s įrašykite duomenų bazės naudotojo vardą.",
    "%s enter the database name." : "%s įrašykite duomenų bazės pavadinimą.",
    "%s you may not use dots in the database name" : "%s negalite naudoti taškų duombazės pavadinime",
    "Oracle connection could not be established" : "Nepavyko užmegzti Oracle ryšio",
    "Oracle username and/or password not valid" : "Neteisingas Oracle naudotojo vardas ir/arba slaptažodis",
    "PostgreSQL username and/or password not valid" : "Neteisingas PostgreSQL naudotojo vardas ir/arba slaptažodis",
    "You need to enter details of an existing account." : "Jūs turite suvesti egzistuojančios paskyros duomenis.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nėra palaikomas, %s neveiks tinkamai šioje platformoje. Naudodami prisiimate visą riziką !",
    "For the best results, please consider using a GNU/Linux server instead." : "Geriausiems rezultatams, apsvarstykite galimybę, vietoj šio, naudoti GNU/Linux serverį",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Pašalinkite savo php.ini faile open_basedir nustatymą arba persijunkite į 64-bitų PHP.",
    "Set an admin username." : "Nustatyti administratoriaus naudotojo vardą.",
    "Set an admin password." : "Nustatyti administratoriaus slaptažodį.",
    "Can't create or write into the data directory %s" : "Negalima nuskaityti arba rašyti į duomenų katalogą. %s",
    "Invalid Federated Cloud ID" : "Neteisingas federacinės debesijos ID",
    "Open »%s«" : "Atverti \"%s\"",
    "%1$s via %2$s" : "%1$s per %2$s",
    "You are not allowed to share %s" : "Jums neleidžiama bendrinti %s",
    "Can’t increase permissions of %s" : "Negalima pridėti papildomų %s leidimų",
    "Files can’t be shared with delete permissions" : "Failai negali būti bendrinami su trynimo leidimu.",
    "Files can’t be shared with create permissions" : "Failai negali būti bendrinami su sukūrimo leidimu.",
    "Expiration date is in the past" : "Bendrinimo pabaigos data yra praėjęs laikas",
    "Can’t set expiration date more than %s days in the future" : "Negalima nustatyti galiojimo laiko ilgesnio nei %s dienos.",
    "Click the button below to open it." : "Norėdami atverti failą, spustelėkite mygtuką žemiau.",
    "The requested share does not exist anymore" : "Pageidaujamas bendrinimas daugiau neegzistuoja.",
    "Could not find category \"%s\"" : "Nepavyko rasti kategorijos „%s“",
    "Sunday" : "Sekmadienis",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Sun." : "Sek.",
    "Mon." : "Pir.",
    "Tue." : "Ant.",
    "Wed." : "Tre.",
    "Thu." : "Ket.",
    "Fri." : "Pen.",
    "Sat." : "Šeš.",
    "Su" : "Sk",
    "Mo" : "Pr",
    "Tu" : "An",
    "We" : "Tr",
    "Th" : "Kt",
    "Fr" : "Pn",
    "Sa" : "Št",
    "January" : "Sausis",
    "February" : "Vasaris",
    "March" : "Kovas",
    "April" : "Balandis",
    "May" : "Gegužė",
    "June" : "Birželis",
    "July" : "Liepa",
    "August" : "Rugpjūtis",
    "September" : "Rugsėjis",
    "October" : "Spalis",
    "November" : "Lapkritis",
    "December" : "Gruodis",
    "Jan." : "Sau.",
    "Feb." : "Vas.",
    "Mar." : "Kov.",
    "Apr." : "Bal.",
    "May." : "Geg.",
    "Jun." : "Bir.",
    "Jul." : "Lie.",
    "Aug." : "Rgp.",
    "Sep." : "Rgs.",
    "Oct." : "Spl.",
    "Nov." : "Lap.",
    "Dec." : "Grd.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Naudotojo varde galima naudoti tik sekančius simbolius: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Privalo būti pateiktas tinkamas naudotojo vardas",
    "Username contains whitespace at the beginning or at the end" : "Naudotojo varde pradžioje ar pabaigoje yra tarpas",
    "Username must not consist of dots only" : "Naudotojo vardas negali būti sudarytas tik iš taškų.",
    "A valid password must be provided" : "Slaptažodis turi būti tinkamas",
    "The username is already being used" : "Naudotojo vardas jau yra naudojamas",
    "Could not create user" : "Nepavyko sukurti naudotojo",
    "User disabled" : "Naudotojas išjungtas",
    "Login canceled by app" : "Programėlė nutraukė prisijungimo procesą",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Programėlė \"%1$s\" negali būti įdiegta, nes nėra patenkinamos šios priklausomybės: %2$s",
    "a safe home for all your data" : "saugūs namai visiems jūsų duomenims",
    "File is currently busy, please try again later" : "Failas šiuo metu yra užimtas, prašome vėliau pabandyti dar kartą",
    "Can't read file" : "Nepavyksta perskaityti failo",
    "Application is not enabled" : "Programa neįjungta",
    "Authentication error" : "Tapatybės nustatymo klaida",
    "Token expired. Please reload page." : "Pasibaigė prieigos rakto galiojimas. Prašome įkelti puslapį iš naujo.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Nėra įdiegtos duomenų bazių tvarkyklės (sqlite, mysql, or postgresql)",
    "Cannot write into \"config\" directory" : "Nepavyksta rašyti į \"config\" katalogą!",
    "Cannot write into \"apps\" directory" : "Nepavyksta įrašyti į \"apps\" katalogą",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Tai, dažniausiai, gali būti ištaisyta, suteikiant saityno serveriui rašymo prieigą prie programų katalogo arba uždraudžiant appstore konfigūraciniame kataloge. Žiūrėkite %s",
    "Cannot create \"data\" directory" : "Nepavyksta sukurti katalogo \"data\"",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Tai, dažniausiai, gali būti ištaisyta, suteikiant saityno serveriui rašymo prieigą prie šakninio katalogo. Žiūrėkite %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Teisės gali būti pataisytos, suteikiant saityno serveriui rašymo prieigą prie šakninio katalogo. Žiūrėkite %s",
    "Setting locale to %s failed" : "Nepavyko nustatyti vietos %s",
    "Please install one of these locales on your system and restart your webserver." : "Prašome įdiekite vieną šių lokalių savo sistemoje ir perkraukite žiniatinklio serverį.",
    "Please ask your server administrator to install the module." : "Kreipkitės į savo sistemos administratorių, kad jis įdiegtų modulį.",
    "PHP module %s not installed." : "PHP modulis %s neįdiegtas.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP nustatymas \"%s\" nenustatytas į \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Šių nustatymų pritaikymas php.ini faile, iš naujo paleis Nextcloud",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload yra nustatytas į \"%s\" vietoj numatomos reikšmės \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Norėdami išspręsti šią problemą, nustatykite <code>mbstring.func_overload</code> į <code>0</code> savo php.ini faile",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Reikalinga ne mažesnė nei libxml2 2.7.0 versija. Šiuo metu yra instaliuota %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Atnaujinkite libxml2 versiją ir perkraukite žiniatinklio serverį, kad sutvarkytumėte šią problemą.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduliai yra įdiegti, bet jų vis tiek trūksta?",
    "Please ask your server administrator to restart the web server." : "Kreipkitės į savo sistemos administratorių, kad jis perkrautų žiniatinklio serverį.",
    "PostgreSQL >= 9 required" : "Reikalinga PostgreSQL >= 9",
    "Please upgrade your database version" : "Atnaujinkite duomenų bazės versiją.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Pakeiskite leidimus į 0770, kad šis katalogas negalėtų būti išvardytas kitiems naudotojams.",
    "Your data directory is readable by other users" : "Duomenų katalogą gali skaityti kiti naudotojai",
    "Your data directory must be an absolute path" : "Jūsų duomenų katalogas privalo būti absoliutusis kelias",
    "Check the value of \"datadirectory\" in your configuration" : "Patikrinkite \"duomenų direktorijos\" reikšmę konfigūracijoje.",
    "Your data directory is invalid" : "Neteisingas duomenų katalogas",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Įsitikinkite, kad šakniniame duomenų kataloge yra  yra \".ocdata\" failas.",
    "Action \"%s\" not supported or implemented." : "Veiksmas \"%s\" nepalaikomas ar neįgyvendintas.",
    "Could not obtain lock type %d on \"%s\"." : "Nepavyko gauti užrakto tipo %d ties \"%s\".",
    "Storage unauthorized. %s" : "Saugykla nesankcionuota. %s",
    "Storage incomplete configuration. %s" : "Nepilna saugyklos konfigūracija. %s",
    "Storage connection error. %s" : "Saugyklos sujungimo ryšio klaida. %s",
    "Storage is temporarily not available" : "Saugykla yra laikinai neprieinama",
    "Storage connection timeout. %s" : "Sujungimo su saugykla laikas baigėsi. %s",
    "Create" : "Sukurti",
    "Change" : "Keisti",
    "Delete" : "Ištrinti",
    "Share" : "Bendrinti",
    "Unlimited" : "Neribota",
    "Verifying" : "Tikrinimas",
    "Verifying …" : "Tikrinama...",
    "Verify" : "Patikrinti",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "%s dalinimasis nepavyko, nes sistema nepalaiko šio duomenų tipo %i",
    "Sharing %s failed, because the file does not exist" : "%s dalinimasis nepavyko, nes failas neegzistuoja.     ",
    "Sharing %s failed, because you can not share with yourself" : "%s bendrinimas nepavyko, jūs negalite bendrinti su savimi pačiu.",
    "Sharing %1$s failed, because the user %2$s does not exist" : "Nepavyko bendrinti %1$s, nes naudotojo %2$s nėra",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "Nepavyko bendrinti %1$s, nes šis elementas jau yra bendrinamas su %2$s",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Nepavyko bendrinti %1$s, nes šis elementas jau yra bendrinamas su naudotoju %2$s",
    "Sharing %1$s failed, because the group %2$s does not exist" : "Nepavyko bendrinti %1$s, nes grupės %2$s nėra",
    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "Nepavyko bendrinti %1$s, nes %2$s nėra grupės %3$s narys",
    "You need to provide a password to create a public link, only protected links are allowed" : "Viešoms nuorodoms būtinas slaptažodis, leidžiamos tik apsaugotos nuorodos.",
    "Sharing %s failed, because sharing with links is not allowed" : "Bendrinimas %s nepavyko, kadangi bendrinimas su nuorodomis yra neleidžiamas.",
    "Not allowed to create a federated share with the same user" : "Negalima sukurti federacinį viešinį su tuo pačiu naudotoju",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "Nepavyko bendrinti %1$s, nepavyko rasti %2$s, galbūt, šiuo metu serveris yra nepasiekiamas.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Negalima nustatyti galiojimo pabaigos datos. Bendrinimas negali pasibaigti vėliau nei %s po jo pasidalinimo",
    "Cannot set expiration date. Expiration date is in the past" : "Nepavyko nustatyti galiojimo datos. Galiojimo data yra praėjęs laikas.",
    "Sharing failed, because the user %s is the original sharer" : "Bendrinimas nepavyko, nes naudotojas %s yra bendrintojas.",
    "Sharing %s failed, because resharing is not allowed" : "%s bendrinimas nepavyko, nes perskirstymas yra neleidžiamas.",
    "Sharing %s failed, because the file could not be found in the file cache" : "%s dalinimasis nepavyko, nes failo nepavyko rasti podelyje.   "
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
